@@ -184,7 +184,7 @@ AddWindow (Window w)
 	 */
 	XSelectInput( dpy, w, AS_CLIENT_EVENT_MASK );
 		
-    if( collect_hints( &Scr, w, HINT_ANY, &raw_hints ) )
+    if( collect_hints( ASDefaultScr, w, HINT_ANY, &raw_hints ) )
     {
         if( is_output_level_under_threshold(OUTPUT_LEVEL_HINTS) )
             print_hints( NULL, NULL, &raw_hints );
@@ -264,9 +264,10 @@ AddWindow (Window w)
         on_window_status_changed( tmp_win, False, True );
         if( !place_aswindow( tmp_win ) )
         {
-            LOCAL_DEBUG_OUT( "window status initialization failed for %lX - destroying it", w );
-            Destroy (tmp_win, False);
-            return NULL;
+            LOCAL_DEBUG_OUT( "window status initialization failed for %lX - will put it where it is", w );
+            /* 	Destroy (tmp_win, False);
+            	return NULL;
+			 */
         }
     }
     /* saving window management properties : */
